Internal: e2_Monte_Carlo_EM
e2_Monte_Carlo_EM(
Betah,
Sigmah,
kappa0 = kappa0,
kappastar0 = kappastar0,
sigma20 = sigma20,
s20 = s20,
m,
K,
a1 = a1,
a2 = a2,
d1 = d1,
d2 = d2,
c1 = c1,
c2 = c2,
e2 = e2,
snpnames,
genename
)A matrix of dimension K*m represents the regression coefficients. Each row of this matrix includes the regression coefficients for each trait.
A symmetric block-diagonal matrix of dimension K*m is used. Each block of this matrix shows a positive definite covariance matrix which is an estimated covariance matrix of each trait.
Initial value for kappa.
Initial value for kappastar.
Initial value for sigma2.
Initial value for s2.
Number of variables in the group.
Number of traits.
Hyperparameters of kappa. Default is a1=0.1 and a2=0.1.
Hyperparameters of sigma2. Default is d1=0.1 and d2=0.1.
Hyperparameters of kappastar. Default is c1=0.1 and c2=0.1.
Initial value for doing Monte Carlo EM algorithm to estimate hyperparameter of s2.
Names of variables for the group.
Name of group.